==> pygame-1.9.2_pre20120101.tar.xz: pygame-1.9.2_pre20120101/src/doc/scrap_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in src/ *.doc . */
#define DOC_PYGAMESCRAP "pygame module for clipboard support."

#define DOC_PYGAMESCRAPINIT "init () -> None\nInitializes the scrap module."

#define DOC_PYGAMESCRAPGET "get (type) -> string\nGets the data for the specified type from the clipboard."

#define DOC_PYGAMESCRAPGETTYPES "get_types () -> list\nGets a list of the available clipboard types."

#define DOC_PYGAMESCRAPPUT "put(type, data) -> None\nPlaces data into the clipboard."

#define DOC_PYGAMESCRAPCONTAINS "contains (type) -> bool\nChecks, whether a certain type is available in the clipboard."

#define DOC_PYGAMESCRAPLOST "lost() -> bool\nChecks whether the clipboard is currently owned by the application."

#define DOC_PYGAMESCRAPSETMODE "set_mode(mode) -> None\nSets the clipboard access mode."



/* Docs in a comment... slightly easier to read. */

/*

pygame.scrap
pygame module for clipboard support.

pygame.scrap.init
 init () -> None
Initializes the scrap module.

pygame.scrap.get
 get (type) -> string
Gets the data for the specified type from the clipboard.

pygame.scrap.get_types
 get_types () -> list
Gets a list of the available clipboard types.

pygame.scrap.put
 put(type, data) -> None
Places data into the clipboard.

pygame.scrap.contains
 contains (type) -> bool
Checks, whether a certain type is available in the clipboard.

pygame.scrap.lost
 lost() -> bool
Checks whether the clipboard is currently owned by the application.

pygame.scrap.set_mode
 set_mode(mode) -> None
Sets the clipboard access mode.

*/

==> pygame_1.9.4.post1+dfsg.orig.tar.xz: pygame-1.9.4.post1/src/doc/scrap_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in src/ *.doc . */
#define DOC_PYGAMESCRAP "pygame module for clipboard support."

#define DOC_PYGAMESCRAPINIT "init () -> None\nInitializes the scrap module."

#define DOC_PYGAMESCRAPGET "get (type) -> bytes\nGets the data for the specified type from the clipboard."

#define DOC_PYGAMESCRAPGETTYPES "get_types () -> list\nGets a list of the available clipboard types."

#define DOC_PYGAMESCRAPPUT "put(type, data) -> None\nPlaces data into the clipboard."

#define DOC_PYGAMESCRAPCONTAINS "contains (type) -> bool\nChecks, whether a certain type is available in the clipboard."

#define DOC_PYGAMESCRAPLOST "lost() -> bool\nChecks whether the clipboard is currently owned by the application."

#define DOC_PYGAMESCRAPSETMODE "set_mode(mode) -> None\nSets the clipboard access mode."



/* Docs in a comment... slightly easier to read. */

/*

pygame.scrap
pygame module for clipboard support.

pygame.scrap.init
 init () -> None
Initializes the scrap module.

pygame.scrap.get
 get (type) -> bytes
Gets the data for the specified type from the clipboard.

pygame.scrap.get_types
 get_types () -> list
Gets a list of the available clipboard types.

pygame.scrap.put
 put(type, data) -> None
Places data into the clipboard.

pygame.scrap.contains
 contains (type) -> bool
Checks, whether a certain type is available in the clipboard.

pygame.scrap.lost
 lost() -> bool
Checks whether the clipboard is currently owned by the application.

pygame.scrap.set_mode
 set_mode(mode) -> None
Sets the clipboard access mode.

*/
